@@ -145,8 +145,24 @@ config.macros.viewRevisions = me = {
 			.removeAttr("revName")
 			.removeClass("revisions");
 
+		//remove any revisions still in the store
+		var revisions = $(".revisions");
+		$(".revisions").each(function(index, revision) {
+			var revAttributes = revision.attributes;
+			if ((revAttributes["revname"]) && 
+					(revAttributes["revision"])) {
+				var revName = revAttributes["revname"].value;
+				var revNo = revAttributes["revision"].value;
+				var title = revName + me.revSuffix.format([revNo]);
+
+				if (store.getTiddler(title)) {
+					store.deleteTiddler(title);
+				}
+			}
+		});
+
 		//delete the previous revisions
-		$(".revisions").remove();
+		revisions.remove();
 
 		//remove the cloak
 		$(".revisionCloak").remove();
